==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex.md <==
# AmazonDynamoDbGlobalSecondaryIndex


```text
aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex
```

```text
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')
```



| Illustration | AmazonDynamoDbGlobalSecondaryIndex | AmazonDynamoDbGlobalSecondaryIndexCard | AmazonDynamoDbGlobalSecondaryIndexGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex.png) | ![illustration for AmazonDynamoDbGlobalSecondaryIndex](../../../aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex.Local.png) | ![illustration for AmazonDynamoDbGlobalSecondaryIndexCard](../../../aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndexCard.Local.png) | ![illustration for AmazonDynamoDbGlobalSecondaryIndexGroup](../../../aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndexGroup.Local.png) |




## AmazonDynamoDbGlobalSecondaryIndex

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndex
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndex('AmazonDynamoDbGlobalSecondaryIndex', 'Amazon Dynamo Db Global Secondary Index', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndex
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndex('AmazonDynamoDbGlobalSecondaryIndex', 'Amazon Dynamo Db Global Secondary Index', 'an optional tech label')
@enduml
```

## AmazonDynamoDbGlobalSecondaryIndexCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndexCard
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndexCard('AmazonDynamoDbGlobalSecondaryIndexCard', 'Amazon Dynamo Db Global Secondary Index Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndexCard
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndexCard('AmazonDynamoDbGlobalSecondaryIndexCard', 'Amazon Dynamo Db Global Secondary Index Card', 'an optional description')
@enduml
```

## AmazonDynamoDbGlobalSecondaryIndexGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndexGroup
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndexGroup('AmazonDynamoDbGlobalSecondaryIndexGroup', 'Amazon Dynamo Db Global Secondary Index Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndexGroup
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndexGroup('AmazonDynamoDbGlobalSecondaryIndexGroup', 'Amazon Dynamo Db Global Secondary Index Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex.md <==
# AmazonDynamoDbGlobalSecondaryIndex


```text
aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex
```

```text
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')
```



| Illustration | AmazonDynamoDbGlobalSecondaryIndex | AmazonDynamoDbGlobalSecondaryIndexCard | AmazonDynamoDbGlobalSecondaryIndexGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex.png) | ![illustration for AmazonDynamoDbGlobalSecondaryIndex](../../../aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex.Local.png) | ![illustration for AmazonDynamoDbGlobalSecondaryIndexCard](../../../aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndexCard.Local.png) | ![illustration for AmazonDynamoDbGlobalSecondaryIndexGroup](../../../aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndexGroup.Local.png) |




## AmazonDynamoDbGlobalSecondaryIndex

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndex
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndex('AmazonDynamoDbGlobalSecondaryIndex', 'Amazon Dynamo Db Global Secondary Index', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndex
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndex('AmazonDynamoDbGlobalSecondaryIndex', 'Amazon Dynamo Db Global Secondary Index', 'an optional tech label')
@enduml
```

## AmazonDynamoDbGlobalSecondaryIndexCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndexCard
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndexCard('AmazonDynamoDbGlobalSecondaryIndexCard', 'Amazon Dynamo Db Global Secondary Index Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndexCard
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndexCard('AmazonDynamoDbGlobalSecondaryIndexCard', 'Amazon Dynamo Db Global Secondary Index Card', 'an optional description')
@enduml
```

## AmazonDynamoDbGlobalSecondaryIndexGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndexGroup
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndexGroup('AmazonDynamoDbGlobalSecondaryIndexGroup', 'Amazon Dynamo Db Global Secondary Index Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbGlobalSecondaryIndexGroup
include('aws-20210730/Resource/Database/AmazonDynamoDbGlobalSecondaryIndex')

' renders the element
AmazonDynamoDbGlobalSecondaryIndexGroup('AmazonDynamoDbGlobalSecondaryIndexGroup', 'Amazon Dynamo Db Global Secondary Index Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
